/*
 * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * See the COPYRIGHT file distributed with this work for additional
 * information regarding copyright ownership.
 */


#ifndef ISC_LANG_H
#define ISC_LANG_H 1

/*! \file isc/lang.h */

#ifdef __cplusplus
#define ISC_LANG_BEGINDECLS	extern "C" {
#define ISC_LANG_ENDDECLS	}
#else
#define ISC_LANG_BEGINDECLS
#define ISC_LANG_ENDDECLS
#endif

#endif /* ISC_LANG_H */
