/*
 * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * See the COPYRIGHT file distributed with this work for additional
 * information regarding copyright ownership.
 */

/* $Id: lang.h,v 1.13 2007/06/19 23:47:23 tbox Exp $ */

#ifndef LWRES_LANG_H
#define LWRES_LANG_H 1

/*! \file lwres/lang.h */

#ifdef __cplusplus
#define LWRES_LANG_BEGINDECLS	extern "C" {
#define LWRES_LANG_ENDDECLS	}
#else
#define LWRES_LANG_BEGINDECLS
#define LWRES_LANG_ENDDECLS
#endif

#endif /* LWRES_LANG_H */
