/*
 * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * See the COPYRIGHT file distributed with this work for additional
 * information regarding copyright ownership.
 */

/* $Id: version.h,v 1.9 2007/06/19 23:47:23 tbox Exp $ */

/*! \file lwres/version.h */

#include <lwres/platform.h>

LIBLWRES_EXTERNAL_DATA extern const char lwres_version[];

LIBLWRES_EXTERNAL_DATA extern const unsigned int lwres_libinterface;
LIBLWRES_EXTERNAL_DATA extern const unsigned int lwres_librevision;
LIBLWRES_EXTERNAL_DATA extern const unsigned int lwres_libage;
