/*
 * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * See the COPYRIGHT file distributed with this work for additional
 * information regarding copyright ownership.
 */

/* $Id: int.h,v 1.14 2007/06/19 23:47:23 tbox Exp $ */

#ifndef LWRES_INT_H
#define LWRES_INT_H 1

/*! \file lwres/int.h */

typedef char				lwres_int8_t;
typedef unsigned char			lwres_uint8_t;
typedef short				lwres_int16_t;
typedef unsigned short			lwres_uint16_t;
typedef int				lwres_int32_t;
typedef unsigned int			lwres_uint32_t;
typedef long long			lwres_int64_t;
typedef unsigned long long		lwres_uint64_t;

#endif /* LWRES_INT_H */
